// parameters:
//      dSUID: device dSUID

dSS.devprops.ShadeCalibrationWizard = Ext.extend(Ext.Window, {
    constructor: function(config) {
        if (config.dSUID === undefined) {
           throw dSS._("Missing dSUID");
        }

        this.currentStep = 0;

        this.dSUID = config.dSUID;

        var devStore = dSS.data.Loader.getDeviceStore();
        var record = devStore.getById(this.dSUID);
        if (record === undefined) {
            throw dSS._("Device not found");
        }

        var devInfo = dSS.util.parseProductID(record.get('productID'));
        var type = devInfo[0];
        var number = devInfo[1];
        var cls = dSS.util.parseFunctionID(record.get('functionID'));
        var group = cls[0];

        if (group !== dSS.config.groups.SHADOW) {
            throw dSS._("Unsupported device group");
        }

        if (dSS.config.deviceTypes[type] !== "KL") {
            throw dSS._("Unsupported device type");
        }

        var text1 = dSS._("Use the arrow buttons below to move the shutter to the " +
                          "upmost position. In case that your shutter was " +
                          "already in the upmost position before calibration " +
                          "was started, you will have to move it a couple of " +
                          "centimeters down and then up, to ensure the " +
                          "correct end position. Please press 'Continue' to " +
                          "automatically lower the shutter.");

        var text2 = dSS._("The shutter is now moving to the lowest " +
                          "position. Various parameters are calculated " +
                          "during that time. Please press 'Continue' as soon " +
                          "as the shutter reaches the lowest position, it " +
                          "will then move up again. The calibration needs " +
                          "to be cancelled and restarted in case that " +
                          "the lowest position was not reached.");

        var text3 = dSS._("The shutter is now moving to the upmost " +
                          "position. Various parameters are calculated " +
                          "during that time. Please klick 'Finish' when the " +
                          "upmost position is reached. The calibration needs " +
                          "to be restarted in case that the upmost position " +
                          "was not reached.");

        if ((number === 220) || (number === 230)) {
            text1 = dSS._("Use the arrow buttons below to move the jalousie to the " +
                          "upmost position. In case that your jalousie was " +
                          "already in the upmost position before calibration " +
                          "was started, you will have to move it a couple of " +
                          "centimeters down and then up, to ensure the " +
                          "correct end position. Please press 'Continue' to " +
                          "automatically lower the jalousie.");

            text2 = dSS._("The jalousie is now moving to the lowest " +
                          "position. Various parameters are calculated " +
                          "during that time. Please press 'Continue' as soon " +
                          "as the jalousie reaches the lowest position, it " +
                          "will then move up again. The calibration needs " +
                          "to be cancelled and restarted in case that " +
                          "the lowest position was not reached.");

            text3 = dSS._("The jalousie is now moving to the upmost " +
                          "position. Various parameters are calculated " +
                          "during that time. Please klick 'Finish' when the " +
                          "upmost position is reached. The calibration needs " +
                          "to be restarted in case that the upmost position " +
                          "was not reached.");
        } else if (number === 210) {
            text1 = dSS._("Use the arrow buttons below to fully open the marquee. " +
                          "In case that your marquee was " +
                          "already open before calibration " +
                          "was started, you will close it a little bit and " +
                          "then fully open it again, to ensure the " +
                          "correct end position. Please press 'Continue' to " +
                          "automatically close the marquee.");

            text2 = dSS._("The marquee is now closing, various parameters " +
                          "are calculated during that time. Please press " +
                          "'Continue' as soon as the marquee reaches the " +
                          "end position, it will then fully open again. " +
                          "The calibration needs to be cancelled and " +
                          "restarted in case that the end position was not " +
                          "reached.");

            text3 = dSS._("The marquee is now opening. Various parameters " +
                          "are calculated during that time. Please klick " +
                          "'Finish' when the upmost position is reached. " +
                          "The calibration needs to be restarted in case " +
                          "that the marquee was not fully opened.");
        }

        this.cancelButton = new Ext.Button({
            xtype: 'button',
            text: dSS._("Cancel"),
            width: 80,
            scope: this,
            handler: function() {
                this.stopProgmode();
                this.close();
            }
        });

        this.contButton = new Ext.Button({
            text: dSS._("Continue"),
            handler: this.nextStep.createDelegate(this),
            disabled: true,
            width: 80
        });

        Ext.apply(this, {
            layout: 'card',
            closable: false,
            padding: 10,
            width: 500,
            height: 230,
            resizable: false,
            modal: true,
            title: dSS._("Calibration - step 1 of 3"),
            items:
            [
                {
                    xtype: 'panel',
                    ref: 'step1',
                    height: 145,
                    layout: 'border',
                    border: false,
                    items:
                    [
                        {
                            xtype: 'panel',
                            region: 'north',
                            height: 122,
                            html: text1,
                            border: false,
                            bodyCfg: {
                                cls: 'x-window-body x-window-mc'
                            }
                        },
                        {
                            xtype: 'panel',
                            border: false,
                            region: 'center',
                            bodyCfg: {
                                cls: 'x-window-body x-window-mc'
                            },
                            layout: 'hbox',
                            items:
                            [
                                {
                                    xtype: 'box',
                                    flex: 3
                                },
                                {
                                    xtype: 'button',
                                    iconCls: 'buttonLeftIcon',
                                    ref: 'decButton',
                                    width: 79,
                                    handler: this.handleMin.createDelegate(this)
                                },
                                {
                                    xtype: 'box',
                                    width: 6
                                },
                                {
                                    xtype: 'button',
                                    ref: 'stopButton',
                                    text: dSS._("Stop"),
                                    width: 79,
                                    handler:
                                        this.handleStop.createDelegate(this)
                                },
                                {
                                    xtype: 'box',
                                    width: 6
                                },
                                {
                                    xtype: 'button',
                                    iconCls: 'buttonRightIcon',
                                    ref: 'incButton',
                                    width: 79,
                                    handler: this.handleMax.createDelegate(this)
                                }
                            ]
                        }
                    ]
                },
                {
                    xtype: 'panel',
                    hidden: true,
                    layout: 'border',
                    height: 145,
                    border: false,
                    ref: 'step2',
                    items:
                    [
                        {
                            xtype: 'panel',
                            region: 'north',
                            height: 122,
                            html: text2,
                            border: false,
                            bodyCfg: {
                                cls: 'x-window-body x-window-mc'
                            }
                        },
                        {
                            xtype: 'panel',
                            region: 'center',
                            border: false,
                            bodyCfg: {
                                cls: 'x-window-body x-window-mc'
                            },
                            layout: 'hbox',
                            items:
                            [
                                {
                                    xtype: 'box',
                                    flex: 3
                                },
                                {
                                    xtype: 'button',
                                    text: dSS._("Stop"),
                                    width: 79,
                                    handler:
                                        this.handleStop.createDelegate(this)
                                }
                            ]
                        }
                    ]
                },
                {
                    xtype: 'panel',
                    hidden: true,
                    layout: 'border',
                    border: false,
                    height: 145,
                    ref: 'step3',
                    items:
                    [
                        {
                            xtype: 'panel',
                            region: 'north',
                            height: 122,
                            html: text3,
                            border: false,
                            bodyCfg: {
                                cls: 'x-window-body x-window-mc'
                            }
                        },
                        {
                            xtype: 'panel',
                            region: 'center',
                            border: false,
                            bodyCfg: {
                                cls: 'x-window-body x-window-mc'
                            },
                            layout: 'hbox',
                            items:
                            [
                                {
                                    xtype: 'box',
                                    flex: 3
                                },
                                {
                                    xtype: 'button',
                                    text: dSS._("Stop"),
                                    width: 79,
                                    handler:
                                        this.handleStop.createDelegate(this)
                                }
                            ]
                        }
                    ]
                }
            ],
            buttons:
            [
                this.contButton,
                this.cancelButton
            ]
        });

        dSS.devprops.ShadeCalibrationWizard.superclass.constructor.apply(this,
                arguments);

        this.on('afterrender', function() {
                this.step1.show();
                this.step2.hide();
                this.step3.hide();
            },
            this);
    },
    handleMin: function() {
        dSS.util.callScene(this.dSUID, dSS.config.scenes.MIN);
        this.lastCalledScene = dSS.config.scenes.MIN;
        this.contButton.enable();
    },
    handleStop: function() {
        dSS.util.callScene(this.dSUID, dSS.config.scenes.STOP);
        this.lastCalledScene = dSS.config.scenes.STOP;
        if (this.currentStep < 2) {
            this.contButton.disable();
        }
    },
    handleMax: function() {
        dSS.util.callScene(this.dSUID, dSS.config.scenes.MAX);
        this.lastCalledScene = dSS.config.scenes.MAX;
        this.contButton.enable();
    },
    unmask2: function() {
        this.el.unmask();
    },
    nextStep: function() {
        switch (this.currentStep)
        {
            case 0:
                this.currentStep++;
                this.step2.show();
                this.step1.hide();
                this.setTitle(dSS._("Calibration - step 2 of 3"));
                if (this.lastCalledScene === dSS.config.scenes.MAX) {
                    dSS.util.callScene(this.dSUID, dSS.config.scenes.INC);
                    dSS.util.callScene.defer(1500, this, [ this.dSUID,
                                             dSS.config.scenes.MIN ]);
                    this.lastCalledScene = dSS.config.scenes.MIN;
                } else {
                    dSS.util.callScene(this.dSUID, dSS.config.scenes.DEC);
                    dSS.util.callScene.defer(1500, this, [ this.dSUID,
                                             dSS.config.scenes.MAX ]);
                    this.lastCalledScene = dSS.config.scenes.MAX;
                }
                this.el.mask(dSS._("Please wait") + "...", 'x-mask-loading');
                this.unmask2.defer(2000, this);
                break;
            case 1:
                this.currentStep++;
                this.step3.show();
                this.step2.hide();
                this.setTitle(dSS._("Calibration - step 3 of 3"));
                if (this.lastCalledScene === dSS.config.scenes.MIN) {
                    dSS.util.callScene(this.dSUID, dSS.config.scenes.MAX);
                } else {
                    dSS.util.callScene(this.dSUID, dSS.config.scenes.MIN);
                }
                this.contButton.hide();
                this.cancelButton.setText(dSS._("Finish"));
                break;
            default:
                this.stopProgmode();
                this.close();
                break;
        }
    },
    stopProgmode: function() {
        dSS.util.genericRequest({
                url: '/json/device/setProgMode',
                params: {
                    dsuid: this.dSUID,
                    mode: 'disable'
                },
                scope: this
            }
        );
    }
});

Ext.reg('dssdevshadecalibrationwizard', dSS.devprops.ShadeCalibrationWizard);

